@@ -6,6 +6,9 @@ from typing import List
 import click
 from tabulate import tabulate
 
+from launchable.utils.key_value_type import normalize_key_value_types
+from launchable.utils.link import LinkKind, capture_link
+
 from ...utils import subprocess
 from ...utils.authentication import get_org_workspace
 from ...utils.click import KeyValueType
@@ -63,9 +66,17 @@ from .commit import commit
     default=[],
     cls=KeyValueType,
 )
+@click.option(
+    '--link',
+    'links',
+    help="Set external link of title and url",
+    multiple=True,
+    default=[],
+    cls=KeyValueType,
+)
 @click.pass_context
 def build(ctx: click.core.Context, build_name: str, source: List[str], max_days: int, no_submodules: bool,
-          no_commit_collection: bool, scrub_pii: bool, commits: List[str]):
+          no_commit_collection: bool, scrub_pii: bool, commits: List[str], links: List[str]):
 
     if "/" in build_name or "%2f" in build_name.lower():
         sys.exit("--name must not contain a slash and an encoded slash")
@@ -77,7 +88,8 @@ def build(ctx: click.core.Context, build_name: str, source: List[str], max_days:
     clean_session_files(days_ago=14)
 
     # This command accepts REPO_NAME=REPO_DIST and REPO_DIST
-    repos = [s.split('=') if re.match(r'[^=]+=[^=]+', s) else (s, s) for s in source]
+    pattern = re.compile(r'[^=]+=[^=]+')
+    repos = [s.split('=') if pattern.match(s) else (s, s) for s in source]
     # TODO: if repo_dist is absolute path, warn the user that that's probably
     # not what they want to do
 
@@ -121,6 +133,7 @@ def build(ctx: click.core.Context, build_name: str, source: List[str], max_days:
 
     submodules = []
     if detect_submodules:
+        submodule_pattern = re.compile(r"^[\+\-U ](?P<hash>[a-f0-9]{40}) (?P<name>\S+)")
         for repo_name, repo_dist in repos:
             # invoke git directly because dulwich's submodule feature was
             # broken
@@ -129,7 +142,7 @@ def build(ctx: click.core.Context, build_name: str, source: List[str], max_days:
             for submodule_stdout in submodule_stdouts:
                 # the output is e.g.
                 # "+bbf213437a65e82dd6dda4391ecc5d598200a6ce sub1 (heads/master)"
-                matched = re.search(r"^[\+\-U ](?P<hash>[a-f0-9]{40}) (?P<name>\S+)", submodule_stdout)
+                matched = submodule_pattern.search(submodule_stdout)
                 if matched:
                     commit_hash = matched.group('hash')
                     name = matched.group('name')
@@ -138,17 +151,11 @@ def build(ctx: click.core.Context, build_name: str, source: List[str], max_days:
 
     if len(commits) != 0:
         invalid = False
-        _commits = []
-        # TODO: handle extraction of flavor tuple to dict in better way for
-        # >=click8.0 that returns tuple of tuples as tuple of str
-        if isinstance(commits[0], str):
-            for c in commits:
-                k, v = c.replace("(", "").replace(")", "").replace("'", "").split(",")
-                _commits.append((k.strip(), v.strip()))
-        else:
-            _commits = commits
+        _commits = normalize_key_value_types(commits)
+
+        commit_pattern = re.compile("[0-9A-Fa-f]{5,40}$")
         for repo_name, hash in _commits:
-            if not re.match("[0-9A-Fa-f]{5,40}$", hash):
+            if not commit_pattern.match(hash):
                 click.echo(click.style(
                     "{}'s commit hash `{}` is invalid.".format(repo_name, hash),
                     fg="yellow"),
@@ -174,9 +181,19 @@ def build(ctx: click.core.Context, build_name: str, source: List[str], max_days:
 
         payload = {
             "buildNumber": build_name,
-            "commitHashes": commitHashes
+            "commitHashes": commitHashes,
         }
 
+        _links = capture_link(os.environ)
+        if len(links) != 0:
+            for link in normalize_key_value_types(links):
+                _links.append({
+                    "title": link[0],
+                    "url": link[1],
+                    "kind": LinkKind.CUSTOM_LINK.name,
+                })
+        payload["links"] = _links
+
         client = LaunchableClient(dry_run=ctx.obj.dry_run)
 
         res = client.request("post", "builds", payload=payload)
