@@ -1,19 +1,19 @@
 import os
-import click
-import sys
 import subprocess
-from urllib.parse import urlparse
+import sys
 from typing import List, Optional
+from urllib.parse import urlparse
 
+import click
+
+from ...utils.commit_ingester import upload_commits
 from ...utils.env_keys import REPORT_ERROR_KEY
 from ...utils.git_log_parser import parse_git_log
-from ...utils.commit_ingester import upload_commits
 from ...utils.http_client import get_base_url
-from ...utils.java import get_java_command, cygpath
-from ...utils.logger import Logger, LOG_LEVEL_AUDIT
+from ...utils.java import cygpath, get_java_command
+from ...utils.logger import LOG_LEVEL_AUDIT, Logger
 
-jar_file_path = os.path.normpath(
-    os.path.join(os.path.dirname(__file__), "../../jar/exe_deploy.jar"))
+jar_file_path = os.path.normpath(os.path.join(os.path.dirname(__file__), "../../jar/exe_deploy.jar"))
 
 
 @click.command()
@@ -60,7 +60,8 @@ def commit(ctx, source: str, executable: bool, max_days: int, scrub_pii: bool, i
             raise e
         else:
             click.echo(click.style(
-                "Can't get commit history from `{}`. Do you run command root of git-controlled directory? If not, please set a directory use by --source option."
+                "Can't get commit history from `{}`. Do you run command root of git-controlled directory? "
+                "If not, please set a directory use by --source option."
                 .format(os.path.abspath(source)),
                 fg='yellow'),
                 err=True)
@@ -112,9 +113,8 @@ def _import_git_log(output_file: str, dry_run: bool):
         if os.getenv(REPORT_ERROR_KEY):
             raise e
         else:
-            click.echo(click.style(
-                "Failed to import the git-log output",
-                fg='yellow'),
+            click.echo(
+                click.style("Failed to import the git-log output", fg='yellow'),
                 err=True)
             print(e)
 
@@ -123,8 +123,7 @@ def _build_proxy_option(https_proxy: Optional[str]) -> List[str]:
     if not https_proxy:
         return []
 
-    if not (https_proxy.startswith("https://")
-            or https_proxy.startswith("http://")):
+    if not (https_proxy.startswith("https://") or https_proxy.startswith("http://")):
         https_proxy = "https://" + https_proxy
     proxy_url = urlparse(https_proxy)
 
