@@ -126,6 +126,14 @@ from .test_path_writer import TestPathWriter
     help='Ignore flaky tests above the value set by this option.You can confirm flaky scores in WebApp',
     type=click.FloatRange(min=0, max=1.0),
 )
+@click.option(
+    '--link',
+    'links',
+    help="Set external link of title and url",
+    multiple=True,
+    default=[],
+    cls=KeyValueType,
+)
 @click.pass_context
 def subset(
     context: click.core.Context,
@@ -144,6 +152,7 @@ def subset(
     is_get_tests_from_previous_sessions: bool,
     is_output_exclusion_rules: bool,
     ignore_flaky_tests_above: Optional[float],
+    links: List[str] = [],
 ):
 
     if is_observation and is_get_tests_from_previous_sessions:
@@ -161,6 +170,7 @@ def subset(
         build_name=build_name,
         flavor=flavor,
         is_observation=is_observation,
+        links=links,
     )
     file_path_normalizer = FilePathNormalizer(base_path, no_base_path_inference=no_base_path_inference)
 
@@ -439,7 +449,7 @@ def subset(
                     err=True)
 
             click.echo("", err=True)
-            click.echo(tabulate(rows, header, tablefmt="github"), err=True)
+            click.echo(tabulate(rows, header, tablefmt="github", floatfmt=".2f"), err=True)
 
             click.echo(
                 "\nRun `launchable inspect subset --subset-id {}` to view full subset details".format(subset_id),
