@@ -1,7 +1,7 @@
 import os
 from typing import List
 
-import click
+import click  # type: ignore
 
 from ..utils.file_name_pattern import jvm_test_pattern
 from . import launchable
